@@ -2,18 +2,16 @@
 :author:
 
 Amine SEHILI <amine.sehili@gmail.com>
-2015-2018
+2015-2021
 
 :License:
 
-This package is published under GNU GPL Version 3.
+This package is published under the MIT license.
 """
 
-from __future__ import absolute_import
 from .core import *
 from .io import *
 from .util import *
-from . import dataset
 from .exceptions import *
 
-__version__ = "0.1.8"
+__version__ = "0.2.0"
